@@ -496,46 +496,6 @@ test_get_providers (void)
 	g_list_free (providers_get);
 }
 
-static void
-test_n_proposals (void)
-{
-	GtkSourceCompletionModel *model;
-	GtkSourceCompletionProvider *provider;
-	GtkSourceCompletionProvider *other_provider;
-	GList *list_providers = NULL;
-	GList *list_proposals = NULL;
-	guint nb_proposals_good = 0;
-	guint nb_proposals_get = 0;
-
-	model = gtk_source_completion_model_new ();
-	provider = GTK_SOURCE_COMPLETION_PROVIDER (test_provider_new ());
-	other_provider = GTK_SOURCE_COMPLETION_PROVIDER (test_provider_new ());
-	list_providers = g_list_append (NULL, provider);
-	list_proposals = create_proposals ();
-
-	gtk_source_completion_model_add_proposals (model, provider, list_proposals);
-
-	g_assert (gtk_source_completion_model_n_proposals (model, other_provider) == 0);
-
-	/* With header */
-	gtk_source_completion_model_set_show_headers (model, TRUE);
-
-	nb_proposals_good = g_list_length (list_proposals);
-	nb_proposals_get = gtk_source_completion_model_n_proposals (model, provider);
-	g_assert (nb_proposals_good == nb_proposals_get);
-
-	/* Without header */
-	gtk_source_completion_model_set_show_headers (model, FALSE);
-
-	nb_proposals_get = gtk_source_completion_model_n_proposals (model, provider);
-	g_assert (nb_proposals_good == nb_proposals_get);
-
-	g_object_unref (model);
-	g_object_unref (other_provider);
-	g_list_free_full (list_providers, g_object_unref);
-	g_list_free_full (list_proposals, g_object_unref);
-}
-
 static void
 test_iters_impl (gboolean show_headers)
 {
@@ -549,17 +509,17 @@ test_iters_impl (gboolean show_headers)
 	gint nb_items;
 	gint *indices;
 
-	/* Test iter_last() */
-	g_assert (!gtk_source_completion_model_iter_last (model, &last_iter));
+	/* Test last_proposal() */
+	g_assert (!gtk_source_completion_model_last_proposal (model, &last_iter));
 
 	create_providers (&all_providers, &all_list_proposals);
 	populate_model (model, all_providers, all_list_proposals);
 
 	gtk_source_completion_model_set_show_headers (model, show_headers);
 
-	g_assert (gtk_source_completion_model_iter_last (model, &last_iter));
+	g_assert (gtk_source_completion_model_last_proposal (model, &last_iter));
 
-	/* Get the last iter by another means, and compare it */
+	/* Get the last proposal by another means, and compare it */
 	nb_items = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (model), NULL);
 
 	g_assert (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (model),
@@ -666,9 +626,6 @@ main (int argc, char **argv)
 	g_test_add_func ("/CompletionModel/get-providers",
 			 test_get_providers);
 
-	g_test_add_func ("/CompletionModel/n-proposals",
-			 test_n_proposals);
-
 	g_test_add_func ("/CompletionModel/iters",
 			 test_iters);
 
